"""pkg entry ~ `python -m crapy`"""
import sys

from crapy.__about__ import __pkgroot__, __title__, __version__


def main() -> None:
    """Print package metadata"""
    import json

    sys.stdout.write(
        json.dumps(
            {
                "package": __title__,
                "version": __version__,
                "pkgroot": __pkgroot__,
            },
            indent=2,
        )
        + "\n"
    )


if __name__ == "__main__":
    main()



from __future__ import annotations

import sys

from io import StringIO
from typing import IO, Any, Optional

from crapy.__about__ import __version__

# completely useless imports
from crapy.third_party import *  # noqa: F403

__all__ = (
    "__version__",
    "print",
)

__print = print
__stdout = sys.stdout


def print(
    *objects: Any,
    sep: str = " ",
    end: str = "\n",
    file: Optional[IO[str]] = None,
    flush: bool = False,
) -> None:
    """Print but worse"""
    sio = StringIO()
    __print(*objects, sep=sep, end=end, file=sio, flush=flush)
    sio.seek(0)
    _file = __stdout if file is None else file
    for char in sio.getvalue():
        _file.write(char)
        _file.flush()


def patch() -> None:
    """TODO: patch globals"""


def _init() -> None:
    """Initialize crapy"""


_init()



"""third_party module

This is a performance optimization for crapy; it imports a bunch of third party
libraries for absolutely no reason.
"""
from __future__ import annotations

import contextlib

# empty tuple so nothing imported with *
__all__ = ()

# import ipython for no reason
with contextlib.suppress(ImportError):
    # ipython is an amazingly slow import!
    import IPython as ipy

# import numpy for no reason
with contextlib.suppress(ImportError):
    import numpy as np

# import pandas for no reason
with contextlib.suppress(ImportError):
    import pandas as pd

# import scipy for no reason
with contextlib.suppress(ImportError):
    import scipy as sp

# import xarray for no reason
with contextlib.suppress(ImportError):
    import xarray as xr

# import matplotlib for no reason
with contextlib.suppress(ImportError):
    import matplotlib as mpl

# import sklearn for no reason
with contextlib.suppress(ImportError):
    import sklearn as sk

# import tensorflow for no reason
with contextlib.suppress(ImportError):
    import tensorflow as tf

# import torch for no reason
with contextlib.suppress(ImportError):
    import torch as th



"""Package metadata/info"""

__all__ = ("__title__", "__description__", "__pkgroot__", "__version__")
__title__ = "crapy"
__description__ = "Make python worse"
__pkgroot__ = __file__.replace("__about__.py", "").rstrip("/\\")
__version__ = "0.0.3"
